@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from dataclasses import field as dc_field
 from typing import Any
 
-import vapoursynth as vs
+from vstools import core, vs
 
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser
 from .nnedi3 import Nnedi3
@@ -13,8 +13,6 @@ __all__ = [
     'Eedi3', 'Eedi3SS', 'Eedi3SR', 'Eedi3DR'
 ]
 
-core = vs.core
-
 
 @dataclass
 class EEDI3(_Antialiaser):
