@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from dataclasses import field as dc_field
 from typing import Any
 
-import vapoursynth as vs
+from vstools import core, vs
 
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser, _FullInterpolate
 
@@ -12,8 +12,6 @@ __all__ = [
     'Nnedi3', 'Nnedi3SS', 'Nnedi3SR', 'Nnedi3DR'
 ]
 
-core = vs.core
-
 
 @dataclass
 class NNEDI3(_FullInterpolate, _Antialiaser):
