@@ -3,7 +3,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 from typing import Any
 
-import vapoursynth as vs
+from vstools import core, vs
 
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser
 from .nnedi3 import NNEDI3
@@ -12,8 +12,6 @@ __all__ = [
     'Znedi3', 'Znedi3SS', 'Znedi3SR', 'Znedi3DR'
 ]
 
-core = vs.core
-
 
 @dataclass
 class ZNEDI3(_Antialiaser):
